@@ -4,20 +4,24 @@ import errno
 import itertools
 import logging
 import signal
-import sys
 import tokenize
-from typing import Dict, List, Optional, Tuple
-
-try:
-    import multiprocessing
-except ImportError:
-    multiprocessing = None  # type: ignore
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
 
 from flake8 import defaults
 from flake8 import exceptions
 from flake8 import processor
 from flake8 import utils
 
+try:
+    import multiprocessing.pool
+except ImportError:
+    multiprocessing = None  # type: ignore
+
+Results = List[Tuple[str, int, int, str, Optional[str]]]
+
 LOG = logging.getLogger(__name__)
 
 SERIAL_RETRY_ERRNOS = {
@@ -27,7 +31,7 @@ SERIAL_RETRY_ERRNOS = {
     # > In those cases, we should replace the customized Queue Report
     # > class with pep8's StandardReport class to ensure users don't run
     # > into this problem.
-    # > (See also: https://gitlab.com/pycqa/flake8/issues/74)
+    # > (See also: https://github.com/pycqa/flake8/issues/117)
     errno.ENOSPC,
     # NOTE(sigmavirus24): When adding to this list, include the reasoning
     # on the lines before the error code and always append your error
@@ -38,17 +42,10 @@ SERIAL_RETRY_ERRNOS = {
 
 def _multiprocessing_is_fork():  # type () -> bool
     """Class state is only preserved when using the `fork` strategy."""
-    if sys.version_info >= (3, 4):
-        return (
-            multiprocessing
-            # https://github.com/python/typeshed/pull/3415
-            and multiprocessing.get_start_method() == "fork"  # type: ignore
-        )
-    else:
-        return multiprocessing and not utils.is_windows()
+    return multiprocessing and multiprocessing.get_start_method() == "fork"
 
 
-class Manager(object):
+class Manager:
     """Manage the parallelism and checker instances for each plugin and file.
 
     This class will be responsible for the following:
@@ -86,8 +83,8 @@ class Manager(object):
         self.options = style_guide.options
         self.checks = checker_plugins
         self.jobs = self._job_count()
-        self._all_checkers = []  # type: List[FileChecker]
-        self.checkers = []  # type: List[FileChecker]
+        self._all_checkers: List[FileChecker] = []
+        self.checkers: List[FileChecker] = []
         self.statistics = {
             "files": 0,
             "logical lines": 0,
@@ -104,12 +101,11 @@ class Manager(object):
                 self.statistics[statistic] += checker.statistics[statistic]
         self.statistics["files"] += len(self.checkers)
 
-    def _job_count(self):
-        # type: () -> int
+    def _job_count(self) -> int:
         # First we walk through all of our error cases:
         # - multiprocessing library is not present
         # - we're running on windows in which case we know we have significant
-        #   implemenation issues
+        #   implementation issues
         # - the user provided stdin and that's not something we can handle
         #   well
         # - we're processing a diff, which again does not work well with
@@ -166,8 +162,7 @@ class Manager(object):
             )
         return reported_results_count
 
-    def is_path_excluded(self, path):
-        # type: (str) -> bool
+    def is_path_excluded(self, path: str) -> bool:
         """Check if a path is excluded.
 
         :param str path:
@@ -190,8 +185,7 @@ class Manager(object):
             logger=LOG,
         )
 
-    def make_checkers(self, paths=None):
-        # type: (Optional[List[str]]) -> None
+    def make_checkers(self, paths: Optional[List[str]] = None) -> None:
         """Create checkers for each file."""
         if paths is None:
             paths = self.arguments
@@ -200,7 +194,6 @@ class Manager(object):
             paths = ["."]
 
         filename_patterns = self.options.filename
-        running_from_vcs = self.options._running_from_vcs
         running_from_diff = self.options.diff
 
         # NOTE(sigmavirus24): Yes this is a little unsightly, but it's our
@@ -218,10 +211,8 @@ class Manager(object):
             # the event that the argument and the filename are identical.
             # If it was specified explicitly, the user intended for it to be
             # checked.
-            explicitly_provided = (
-                not running_from_vcs
-                and not running_from_diff
-                and (argument == filename)
+            explicitly_provided = not running_from_diff and (
+                argument == filename
             )
             return (
                 explicitly_provided or matches_filename_patterns
@@ -239,8 +230,7 @@ class Manager(object):
         self.checkers = [c for c in self._all_checkers if c.should_process]
         LOG.info("Checking %d files", len(self.checkers))
 
-    def report(self):
-        # type: () -> Tuple[int, int]
+    def report(self) -> Tuple[int, int]:
         """Report all of the errors found in the managed file checkers.
 
         This iterates over each of the checkers and reports the errors sorted
@@ -253,27 +243,23 @@ class Manager(object):
         """
         results_reported = results_found = 0
         for checker in self._all_checkers:
-            results = sorted(
-                checker.results, key=lambda tup: (tup[1], tup[2])
-            )
+            results = sorted(checker.results, key=lambda tup: (tup[1], tup[2]))
             filename = checker.display_name
             with self.style_guide.processing_file(filename):
                 results_reported += self._handle_results(filename, results)
             results_found += len(results)
         return (results_found, results_reported)
 
-    def run_parallel(self):
+    def run_parallel(self) -> None:
         """Run the checkers in parallel."""
         # fmt: off
-        final_results = collections.defaultdict(list)  # type: Dict[str, List[Tuple[str, int, int, str, Optional[str]]]]  # noqa: E501
-        final_statistics = collections.defaultdict(dict)  # type: Dict[str, Dict[str, None]]  # noqa: E501
+        final_results: Dict[str, List[Tuple[str, int, int, str, Optional[str]]]] = collections.defaultdict(list)  # noqa: E501
+        final_statistics: Dict[str, Dict[str, int]] = collections.defaultdict(dict)  # noqa: E501
         # fmt: on
 
-        try:
-            pool = multiprocessing.Pool(self.jobs, _pool_init)
-        except OSError as oserr:
-            if oserr.errno not in SERIAL_RETRY_ERRNOS:
-                raise
+        pool = _try_initialize_processpool(self.jobs)
+
+        if pool is None:
             self.run_serial()
             return
 
@@ -303,19 +289,19 @@ class Manager(object):
             checker.results = final_results[filename]
             checker.statistics = final_statistics[filename]
 
-    def run_serial(self):
+    def run_serial(self) -> None:
         """Run the checkers in serial."""
         for checker in self.checkers:
             checker.run_checks()
 
-    def run(self):
+    def run(self) -> None:
         """Run all the checkers.
 
         This will intelligently decide whether to run the checks in parallel
         or whether to run them in serial.
 
         If running the checks in parallel causes a problem (e.g.,
-        https://gitlab.com/pycqa/flake8/issues/74) this also implements
+        https://github.com/pycqa/flake8/issues/117) this also implements
         fallback to serial processing.
         """
         try:
@@ -342,7 +328,7 @@ class Manager(object):
         self._process_statistics()
 
 
-class FileChecker(object):
+class FileChecker:
     """Manage running checks for a file and aggregate the results."""
 
     def __init__(self, filename, checks, options):
@@ -362,9 +348,7 @@ class FileChecker(object):
         self.options = options
         self.filename = filename
         self.checks = checks
-        # fmt: off
-        self.results = []  # type: List[Tuple[str, int, int, str, Optional[str]]]  # noqa: E501
-        # fmt: on
+        self.results: Results = []
         self.statistics = {
             "tokens": 0,
             "logical lines": 0,
@@ -378,34 +362,37 @@ class FileChecker(object):
             self.should_process = not self.processor.should_ignore_file()
             self.statistics["physical lines"] = len(self.processor.lines)
 
-    def __repr__(self):  # type: () -> str
+    def __repr__(self) -> str:
         """Provide helpful debugging representation."""
-        return "FileChecker for {}".format(self.filename)
+        return f"FileChecker for {self.filename}"
 
-    def _make_processor(self):
-        # type: () -> Optional[processor.FileProcessor]
+    def _make_processor(self) -> Optional[processor.FileProcessor]:
         try:
             return processor.FileProcessor(self.filename, self.options)
-        except IOError as e:
+        except OSError as e:
             # If we can not read the file due to an IOError (e.g., the file
             # does not exist or we do not have the permissions to open it)
             # then we need to format that exception for the user.
             # NOTE(sigmavirus24): Historically, pep8 has always reported this
             # as an E902. We probably *want* a better error code for this
             # going forward.
-            message = "{0}: {1}".format(type(e).__name__, e)
-            self.report("E902", 0, 0, message)
+            self.report("E902", 0, 0, f"{type(e).__name__}: {e}")
             return None
 
-    def report(self, error_code, line_number, column, text):
-        # type: (Optional[str], int, int, str) -> str
+    def report(
+        self,
+        error_code: Optional[str],
+        line_number: int,
+        column: int,
+        text: str,
+    ) -> str:
         """Report an error by storing it in the results list."""
         if error_code is None:
             error_code, text = text.split(" ", 1)
 
         # If we're recovering from a problem in _make_processor, we will not
         # have this attribute.
-        if hasattr(self, "processor"):
+        if hasattr(self, "processor") and self.processor is not None:
             line = self.processor.noqa_line_for(line_number)
         else:
             line = None
@@ -416,6 +403,7 @@ class FileChecker(object):
     def run_check(self, plugin, **arguments):
         """Run the check in a single plugin."""
         LOG.debug("Running %r with %r", plugin, arguments)
+        assert self.processor is not None
         try:
             self.processor.keyword_arguments_for(
                 plugin["parameters"], arguments
@@ -438,23 +426,45 @@ class FileChecker(object):
             )
 
     @staticmethod
-    def _extract_syntax_information(exception):
-        token = ()
-        if len(exception.args) > 1:
+    def _extract_syntax_information(exception: Exception) -> Tuple[int, int]:
+        if (
+            len(exception.args) > 1
+            and exception.args[1]
+            and len(exception.args[1]) > 2
+        ):
             token = exception.args[1]
-            if token and len(token) > 2:
-                row, column = token[1:3]
+            row, column = token[1:3]
+        elif (
+            isinstance(exception, tokenize.TokenError)
+            and len(exception.args) == 2
+            and len(exception.args[1]) == 2
+        ):
+            token = ()
+            row, column = exception.args[1]
         else:
+            token = ()
             row, column = (1, 0)
 
-        if column > 0 and token and isinstance(exception, SyntaxError):
+        if (
+            column > 0
+            and token
+            and isinstance(exception, SyntaxError)
+            and len(token) == 4  # Python 3.9 or earlier
+        ):
             # NOTE(sigmavirus24): SyntaxErrors report 1-indexed column
             # numbers. We need to decrement the column number by 1 at
             # least.
             column_offset = 1
             row_offset = 0
-            # See also: https://gitlab.com/pycqa/flake8/issues/237
-            physical_line = token[-1]
+            # See also: https://github.com/pycqa/flake8/issues/169,
+            # https://github.com/PyCQA/flake8/issues/1372
+            # On Python 3.9 and earlier, token will be a 4-item tuple with the
+            # last item being the string. Starting with 3.10, they added to
+            # the tuple so now instead of it ending with the code that failed
+            # to parse, it ends with the end of the section of code that
+            # failed to parse. Luckily the absolute position in the tuple is
+            # stable across versions so we can use that here
+            physical_line = token[3]
 
             # NOTE(sigmavirus24): Not all "tokens" have a string as the last
             # argument. In this event, let's skip trying to find the correct
@@ -463,7 +473,7 @@ class FileChecker(object):
                 # NOTE(sigmavirus24): SyntaxErrors also don't exactly have a
                 # "physical" line so much as what was accumulated by the point
                 # tokenizing failed.
-                # See also: https://gitlab.com/pycqa/flake8/issues/237
+                # See also: https://github.com/pycqa/flake8/issues/169
                 lines = physical_line.rstrip("\n").split("\n")
                 row_offset = len(lines) - 1
                 logical_line = lines[0]
@@ -474,16 +484,10 @@ class FileChecker(object):
             column -= column_offset
         return row, column
 
-    def run_ast_checks(self):  # type: () -> None
+    def run_ast_checks(self) -> None:
         """Run all checks expecting an abstract syntax tree."""
-        try:
-            ast = self.processor.build_ast()
-        except (ValueError, SyntaxError, TypeError) as e:
-            row, column = self._extract_syntax_information(e)
-            self.report(
-                "E999", row, column, "%s: %s" % (type(e).__name__, e.args[0])
-            )
-            return
+        assert self.processor is not None
+        ast = self.processor.build_ast()
 
         for plugin in self.checks["ast_plugins"]:
             checker = self.run_check(plugin, tree=ast)
@@ -503,6 +507,7 @@ class FileChecker(object):
 
     def run_logical_checks(self):
         """Run all checks expecting a logical line."""
+        assert self.processor is not None
         comments, logical_line, mapping = self.processor.build_logical_line()
         if not mapping:
             return
@@ -531,6 +536,7 @@ class FileChecker(object):
 
         A single physical check may return multiple errors.
         """
+        assert self.processor is not None
         for plugin in self.checks["physical_line_plugins"]:
             self.processor.update_checker_state_for(plugin)
             result = self.run_check(plugin, physical_line=physical_line)
@@ -559,16 +565,17 @@ class FileChecker(object):
     def process_tokens(self):
         """Process tokens and trigger checks.
 
-        This can raise a :class:`flake8.exceptions.InvalidSyntax` exception.
         Instead of using this directly, you should use
         :meth:`flake8.checker.FileChecker.run_checks`.
         """
+        assert self.processor is not None
         parens = 0
         statistics = self.statistics
         file_processor = self.processor
+        prev_physical = ""
         for token in file_processor.generate_tokens():
             statistics["tokens"] += 1
-            self.check_physical_eol(token)
+            self.check_physical_eol(token, prev_physical)
             token_type, text = token[0:2]
             processor.log_token(LOG, token)
             if token_type == tokenize.OP:
@@ -576,24 +583,24 @@ class FileChecker(object):
             elif parens == 0:
                 if processor.token_is_newline(token):
                     self.handle_newline(token_type)
+            prev_physical = token[4]
 
         if file_processor.tokens:
             # If any tokens are left over, process them
             self.run_physical_checks(file_processor.lines[-1])
             self.run_logical_checks()
 
-    def run_checks(self):
+    def run_checks(self) -> Tuple[str, Results, Dict[str, int]]:
         """Run checks against the file."""
+        assert self.processor is not None
         try:
-            self.process_tokens()
             self.run_ast_checks()
-        except exceptions.InvalidSyntax as exc:
-            self.report(
-                exc.error_code,
-                exc.line_number,
-                exc.column_number,
-                exc.error_message,
-            )
+            self.process_tokens()
+        except (SyntaxError, tokenize.TokenError) as e:
+            code = "E902" if isinstance(e, tokenize.TokenError) else "E999"
+            row, column = self._extract_syntax_information(e)
+            self.report(code, row, column, f"{type(e).__name__}: {e.args[0]}")
+            return self.filename, self.results, self.statistics
 
         logical_lines = self.processor.statistics["logical lines"]
         self.statistics["logical lines"] = logical_lines
@@ -601,6 +608,7 @@ class FileChecker(object):
 
     def handle_newline(self, token_type):
         """Handle the logic when encountering a newline token."""
+        assert self.processor is not None
         if token_type == tokenize.NEWLINE:
             self.run_logical_checks()
             self.processor.reset_blank_before()
@@ -611,11 +619,20 @@ class FileChecker(object):
         else:
             self.run_logical_checks()
 
-    def check_physical_eol(self, token):
+    def check_physical_eol(
+        self, token: processor._Token, prev_physical: str
+    ) -> None:
         """Run physical checks if and only if it is at the end of the line."""
+        assert self.processor is not None
+        # a newline token ends a single physical line.
         if processor.is_eol_token(token):
-            # Obviously, a newline token ends a single physical line.
-            self.run_physical_checks(token[4])
+            # if the file does not end with a newline, the NEWLINE
+            # token is inserted by the parser, but it does not contain
+            # the previous physical line in `token[4]`
+            if token[4] == "":
+                self.run_physical_checks(prev_physical)
+            else:
+                self.run_physical_checks(token[4])
         elif processor.is_multiline_string(token):
             # Less obviously, a string that contains newlines is a
             # multiline string, either triple-quoted or with internal
@@ -634,19 +651,34 @@ class FileChecker(object):
                     self.run_physical_checks(line + "\n")
 
 
-def _pool_init():
+def _pool_init() -> None:
     """Ensure correct signaling of ^C using multiprocessing.Pool."""
     signal.signal(signal.SIGINT, signal.SIG_IGN)
 
 
+def _try_initialize_processpool(
+    job_count: int,
+) -> Optional[multiprocessing.pool.Pool]:
+    """Return a new process pool instance if we are able to create one."""
+    try:
+        return multiprocessing.Pool(job_count, _pool_init)
+    except OSError as err:
+        if err.errno not in SERIAL_RETRY_ERRNOS:
+            raise
+    except ImportError:
+        pass
+
+    return None
+
+
 def calculate_pool_chunksize(num_checkers, num_jobs):
     """Determine the chunksize for the multiprocessing Pool.
 
     - For chunksize, see: https://docs.python.org/3/library/multiprocessing.html#multiprocessing.pool.Pool.imap  # noqa
     - This formula, while not perfect, aims to give each worker two batches of
       work.
-    - See: https://gitlab.com/pycqa/flake8/merge_requests/156#note_18878876
-    - See: https://gitlab.com/pycqa/flake8/issues/265
+    - See: https://github.com/pycqa/flake8/issues/829#note_18878876
+    - See: https://github.com/pycqa/flake8/issues/197
     """
     return max(num_checkers // (num_jobs * 2), 1)
 
@@ -655,8 +687,9 @@ def _run_checks(checker):
     return checker.run_checks()
 
 
-def find_offset(offset, mapping):
-    # type: (int, processor._LogicalMapping) -> Tuple[int, int]
+def find_offset(
+    offset: int, mapping: processor._LogicalMapping
+) -> Tuple[int, int]:
     """Find the offset tuple for a single offset."""
     if isinstance(offset, tuple):
         return offset
