@@ -1,15 +1,19 @@
 """The base class and interface for all formatting plugins."""
-from __future__ import print_function
-
 import argparse
-from typing import IO, List, Optional, Tuple
+import os
+import sys
+from typing import IO
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import TYPE_CHECKING
 
-if False:  # `typing.TYPE_CHECKING` was introduced in 3.5.2
+if TYPE_CHECKING:
     from flake8.statistics import Statistics
     from flake8.style_guide import Violation
 
 
-class BaseFormatter(object):
+class BaseFormatter:
     """Class defining the formatter interface.
 
     .. attribute:: options
@@ -31,8 +35,7 @@ class BaseFormatter(object):
         output filename has been specified.
     """
 
-    def __init__(self, options):
-        # type: (argparse.Namespace) -> None
+    def __init__(self, options: argparse.Namespace) -> None:
         """Initialize with the options parsed from config and cli.
 
         This also calls a hook, :meth:`after_init`, so subclasses do not need
@@ -46,14 +49,14 @@ class BaseFormatter(object):
         """
         self.options = options
         self.filename = options.output_file
-        self.output_fd = None  # type: Optional[IO[str]]
+        self.output_fd: Optional[IO[str]] = None
         self.newline = "\n"
         self.after_init()
 
-    def after_init(self):  # type: () -> None
+    def after_init(self) -> None:
         """Initialize the formatter further."""
 
-    def beginning(self, filename):  # type: (str) -> None
+    def beginning(self, filename: str) -> None:
         """Notify the formatter that we're starting to process a file.
 
         :param str filename:
@@ -61,7 +64,7 @@ class BaseFormatter(object):
             from.
         """
 
-    def finished(self, filename):  # type: (str) -> None
+    def finished(self, filename: str) -> None:
         """Notify the formatter that we've finished processing a file.
 
         :param str filename:
@@ -69,15 +72,17 @@ class BaseFormatter(object):
             from.
         """
 
-    def start(self):  # type: () -> None
+    def start(self) -> None:
         """Prepare the formatter to receive input.
 
         This defaults to initializing :attr:`output_fd` if :attr:`filename`
         """
         if self.filename:
+            dirname = os.path.dirname(os.path.abspath(self.filename))
+            os.makedirs(dirname, exist_ok=True)
             self.output_fd = open(self.filename, "a")
 
-    def handle(self, error):  # type: (Violation) -> None
+    def handle(self, error: "Violation") -> None:
         """Handle an error reported by Flake8.
 
         This defaults to calling :meth:`format`, :meth:`show_source`, and
@@ -94,7 +99,7 @@ class BaseFormatter(object):
         source = self.show_source(error)
         self.write(line, source)
 
-    def format(self, error):  # type: (Violation) -> Optional[str]
+    def format(self, error: "Violation") -> Optional[str]:
         """Format an error reported by Flake8.
 
         This method **must** be implemented by subclasses.
@@ -113,23 +118,16 @@ class BaseFormatter(object):
             "Subclass of BaseFormatter did not implement" " format."
         )
 
-    def show_statistics(self, statistics):  # type: (Statistics) -> None
+    def show_statistics(self, statistics: "Statistics") -> None:
         """Format and print the statistics."""
         for error_code in statistics.error_codes():
             stats_for_error_code = statistics.statistics_for(error_code)
             statistic = next(stats_for_error_code)
             count = statistic.count
             count += sum(stat.count for stat in stats_for_error_code)
-            self._write(
-                "{count:<5} {error_code} {message}".format(
-                    count=count,
-                    error_code=error_code,
-                    message=statistic.message,
-                )
-            )
+            self._write(f"{count:<5} {error_code} {statistic.message}")
 
-    def show_benchmarks(self, benchmarks):
-        # type: (List[Tuple[str, float]]) -> None
+    def show_benchmarks(self, benchmarks: List[Tuple[str, float]]) -> None:
         """Format and print the benchmarks."""
         # NOTE(sigmavirus24): The format strings are a little confusing, even
         # to me, so here's a quick explanation:
@@ -150,7 +148,7 @@ class BaseFormatter(object):
                 benchmark = float_format(statistic=statistic, value=value)
             self._write(benchmark)
 
-    def show_source(self, error):  # type: (Violation) -> Optional[str]
+    def show_source(self, error: "Violation") -> Optional[str]:
         """Show the physical line generating the error.
 
         This also adds an indicator for the particular part of the line that
@@ -179,17 +177,16 @@ class BaseFormatter(object):
         )
         # Physical lines have a newline at the end, no need to add an extra
         # one
-        return "{}{}^".format(error.physical_line, indent)
+        return f"{error.physical_line}{indent}^"
 
-    def _write(self, output):  # type: (str) -> None
+    def _write(self, output: str) -> None:
         """Handle logic of whether to use an output file or print()."""
         if self.output_fd is not None:
             self.output_fd.write(output + self.newline)
         if self.output_fd is None or self.options.tee:
-            print(output, end=self.newline)
+            sys.stdout.buffer.write(output.encode() + self.newline.encode())
 
-    def write(self, line, source):
-        # type: (Optional[str], Optional[str]) -> None
+    def write(self, line: Optional[str], source: Optional[str]) -> None:
         """Write the line either to the output file or stdout.
 
         This handles deciding whether to write to a file or print to standard
@@ -207,7 +204,7 @@ class BaseFormatter(object):
         if source:
             self._write(source)
 
-    def stop(self):  # type: () -> None
+    def stop(self) -> None:
         """Clean up after reporting is finished."""
         if self.output_fd is not None:
             self.output_fd.close()
