@@ -3,26 +3,27 @@ import collections
 import configparser
 import logging
 import os.path
-from typing import List, Optional, Tuple
+from typing import List
+from typing import Optional
+from typing import Tuple
 
 from flake8 import utils
 
 LOG = logging.getLogger(__name__)
 
-__all__ = ("ConfigFileFinder", "MergedConfigParser")
+__all__ = ("ConfigFileFinder", "ConfigParser")
 
 
-class ConfigFileFinder(object):
+class ConfigFileFinder:
     """Encapsulate the logic for finding and reading config files."""
 
     def __init__(
         self,
-        program_name,
-        extra_config_files=None,
-        config_file=None,
-        ignore_config_files=False,
-    ):
-        # type: (str, Optional[List[str]], Optional[str], bool) -> None
+        program_name: str,
+        extra_config_files: Optional[List[str]] = None,
+        config_file: Optional[str] = None,
+        ignore_config_files: bool = False,
+    ) -> None:
         """Initialize object to find config files.
 
         :param str program_name:
@@ -47,30 +48,16 @@ class ConfigFileFinder(object):
 
         # User configuration file.
         self.program_name = program_name
-        self.user_config_file = self._user_config_file(program_name)
 
         # List of filenames to find in the local/project directory
-        self.project_filenames = ("setup.cfg", "tox.ini", "." + program_name)
+        self.project_filenames = ("setup.cfg", "tox.ini", f".{program_name}")
 
         self.local_directory = os.path.abspath(os.curdir)
 
     @staticmethod
-    def _user_config_file(program_name):
-        # type: (str) -> str
-        if utils.is_windows():
-            home_dir = os.path.expanduser("~")
-            config_file_basename = "." + program_name
-        else:
-            home_dir = os.environ.get(
-                "XDG_CONFIG_HOME", os.path.expanduser("~/.config")
-            )
-            config_file_basename = program_name
-
-        return os.path.join(home_dir, config_file_basename)
-
-    @staticmethod
-    def _read_config(*files):
-        # type: (*str) -> Tuple[configparser.RawConfigParser, List[str]]
+    def _read_config(
+        *files: str,
+    ) -> Tuple[configparser.RawConfigParser, List[str]]:
         config = configparser.RawConfigParser()
 
         found_files = []
@@ -91,8 +78,7 @@ class ConfigFileFinder(object):
                 )
         return (config, found_files)
 
-    def cli_config(self, files):
-        # type: (str) -> configparser.RawConfigParser
+    def cli_config(self, files: str) -> configparser.RawConfigParser:
         """Read and parse the config file specified on the command-line."""
         config, found_files = self._read_config(files)
         if found_files:
@@ -146,15 +132,8 @@ class ConfigFileFinder(object):
         """Parse all local config files into one config object."""
         return self.local_configs_with_files()[0]
 
-    def user_config(self):
-        """Parse the user config file into a config object."""
-        config, found_files = self._read_config(self.user_config_file)
-        if found_files:
-            LOG.debug("Found user configuration files: %s", found_files)
-        return config
 
-
-class MergedConfigParser(object):
+class ConfigParser:
     """Encapsulate merging different types of configuration files.
 
     This parses out the options registered that were specified in the
@@ -167,7 +146,7 @@ class MergedConfigParser(object):
     GETBOOL_ACTIONS = {"store_true", "store_false"}
 
     def __init__(self, option_manager, config_finder):
-        """Initialize the MergedConfigParser instance.
+        """Initialize the ConfigParser instance.
 
         :param flake8.options.manager.OptionManager option_manager:
             Initialized OptionManager.
@@ -239,19 +218,6 @@ class MergedConfigParser(object):
         LOG.debug("Parsing local configuration files.")
         return self._parse_config(config)
 
-    def parse_user_config(self):
-        """Parse and return the user configuration files."""
-        config = self.config_finder.user_config()
-        if not self.is_configured_by(config):
-            LOG.debug(
-                "User configuration files have no %s section",
-                self.program_name,
-            )
-            return {}
-
-        LOG.debug("Parsing user configuration files.")
-        return self._parse_config(config)
-
     def parse_cli_config(self, config_path):
         """Parse and return the file specified by --config."""
         config = self.config_finder.cli_config(config_path)
@@ -265,28 +231,8 @@ class MergedConfigParser(object):
         LOG.debug("Parsing CLI configuration files.")
         return self._parse_config(config, os.path.dirname(config_path))
 
-    def merge_user_and_local_config(self):
-        """Merge the parsed user and local configuration files.
-
-        :returns:
-            Dictionary of the parsed and merged configuration options.
-        :rtype:
-            dict
-        """
-        user_config = self.parse_user_config()
-        config = self.parse_local_config()
-
-        for option, value in user_config.items():
-            config.setdefault(option, value)
-
-        return config
-
     def parse(self):
-        """Parse and return the local and user config files.
-
-        First this copies over the parsed local configuration and then
-        iterates over the options in the user configuration and sets them if
-        they were not set by the local configuration file.
+        """Parse and return the local config files.
 
         :returns:
             Dictionary of parsed configuration options
@@ -309,7 +255,7 @@ class MergedConfigParser(object):
             )
             return self.parse_cli_config(self.config_finder.config_file)
 
-        return self.merge_user_and_local_config()
+        return self.parse_local_config()
 
 
 def get_local_plugins(config_finder):
@@ -344,7 +290,7 @@ def get_local_plugins(config_finder):
 
     base_dirs = {os.path.dirname(cf) for cf in config_files}
 
-    section = "%s:local-plugins" % config_finder.program_name
+    section = f"{config_finder.program_name}:local-plugins"
     for plugin_type in ["extension", "report"]:
         if config.has_option(section, plugin_type):
             local_plugins_string = config.get(section, plugin_type).strip()
@@ -358,7 +304,7 @@ def get_local_plugins(config_finder):
         raw_paths = utils.parse_comma_separated_list(
             config.get(section, "paths").strip()
         )
-        norm_paths = []  # type: List[str]
+        norm_paths: List[str] = []
         for base_dir in base_dirs:
             norm_paths.extend(
                 path
@@ -369,6 +315,4 @@ def get_local_plugins(config_finder):
     return local_plugins
 
 
-LocalPlugins = collections.namedtuple(
-    "LocalPlugins", "extension report paths"
-)
+LocalPlugins = collections.namedtuple("LocalPlugins", "extension report paths")
